GenerateBlocUI class
An annotation used to specify a class to generate code for.
Constructors
-
GenerateBlocUI({Set<
String> selectorClasses = const <String>{}}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectorClasses
→ Set<
String> -
Defines classes for which
BlocSelectors should be generated. If empty, noBlocSelectors are generated at all.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited